%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Filtering the History %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all; clear all; clc

addpath('results');
addpath('utils');

%% Load model
try load model.mat
catch a1_readmodel
end

%% Load data
try load data.mat
catch a2_readdata
end

%load the database
dm = dbload('data/cz_monthly.csv');
dq = dbload('data/cz_quarterly.csv');
dy = dbload('data/cz_yearly.csv');

%% Set the estimation range
sdate = qq(1999,1);
edate = qq(2016,3);

rng   = sdate:endhist+8;
hglt = endhist(end)+1:rng(end);

%% Switcers for reporting

doFilterReport = true;
doShockDecompReport = false;

%% %%%% TUNES %%%%%%

ynames = get(m,'ynames');

for ind = 1:length(ynames)
    if ~isfield(dObs,(ynames{ind}))
    dObs.(ynames{ind}) = tseries();
    end
end

dObs.OBS_D4L_GDP(qq(2016,3))    = 100*log(1+2.2/100);

dObs.OBS_L_Z_GAP(qq(2011,1)) = 0;

dObs.OBS_L_Z_GAP(qq(2014,1)) = -4;

%% fcast tunes

dObs.OBS_D4L_CPI_TAR(qq(1999,1):qq(2005,4)) = 100*log(1+3/100);
dObs.OBS_D4L_CPI_TAR(qq(2006,1):qq(2020,4)) = 100*log(1+2/100);

dObs.OBS_DLA_Z_BAR_EUR(qq(2014,1):qq(2018,3)) = 0;

dObs.OBS_L_S_USD_EUR(qq(2016,4):qq(2018,3)) = 100*log([1.1172 1.11 1.10 1.10 1.10 1.10 1.10 1.10]);

dObs.OBS_RR_BAR(qq(2015,1):qq(2015,4)) = -1;


%% Set multipliers on shocks
std_c          = get(m,'std');
list_std       = fieldnames(std_c);
% set multipliers to be equal to one (ie., no multipliciation):
mult           = dbbatch(std_c, '$0', 'tseries(sdate:edate,1)'); 

% computing the rescaled std's
std_mult       = dbbatch(std_c,'$0','mult.$0.*std_c.$0');

disp('Filtering ...');
%% Prepare data for Kalman filter given structure of the model
% Compute smoothed states
[m_filt, smooth] = filter(m,dObs,rng,'std',std_mult);

%% Convert result to database
df    = smooth.mean;
d_std = smooth.std;
d     = dboverlay(dObs, df);

d.L_CPI   = d.OBS_L_CPI;
d.DLA_CPI = 4*diff(d.L_CPI);
d.D4L_CPI = diff(d.L_CPI,-4);

%% Save the data
% save results/filterdata.mat H starthist endhist;
% dbsave(H,['results' filesep 'filterdata.csv']);
save results/filterdata.mat d dObs d_std starthist endhist;
dbsave(d,['results' filesep 'filterdata.csv']);


if doFilterReport
    disp('Filter report...')
    %% Creating variables to the report
    names   = fieldnames(d);
    for ind = 1:length(names)
        if ~isa(d.(names{ind}),'double') & ~strcmp(names{ind},'S')
            if strcmp(names{ind}(1:2),'L_')
                d.(['DOTA_' names{ind}(3:end)]) = 4*pct(exp(d.(names{ind})/100),-1);
                d.(['DOT4_' names{ind}(3:end)]) = pct(exp(d.(names{ind})/100),-4);
            else
                if length(names{ind}) > 3
                    if strcmp(names{ind}(1:4),'D4L_')
                        d.(['DOT4_' names{ind}(5:end)]) = 100*(exp(d.(names{ind})/100))-100;
                    else
                        d.(['DOTA_' names{ind}]) = 4*pct(d.(names{ind}),-1);
                        d.(['DOT4_' names{ind}]) = pct(d.(names{ind}),-4);
                    end
                else
                    d.(['DOTA_' names{ind}]) = 4*pct(d.(names{ind}),-1);
                    d.(['DOT4_' names{ind}]) = pct(d.(names{ind}),-4);
                end
            end
        end
    end
    
    
    %% Creating report
    
    disp('Creating the Filter Report...')
    
    p = get(m, 'parameters');
    d = dboverlay(d, p);
    %keyboard
    % styles
    st1 = struct();
    st1.line.lineWidth = {1.5,1.5};
    st1.line.lineStyle = {'-','--'};
    st1.line.color = {[0,0,0.9],[0,0,0]};
    st1.line.marker = {'none','none'};
    
    st2 = st1;
    st2.line.lineWidth = {1,1};
    
    st3 = st1;
    st3.line.lineStyle = {'-','--','-.'};
    st3.line.Color = {[0,0,0.9],[0,0,0],[0.9,0,0]};
    st3.line.Marker = {'none','none','none'};
    
    sto =struct();
    sto.line.linewidth = {2};
    sto.line.color = {[0,0.9,0],[0,0,0.9],[0.9,0,0],[0.4,0.4,0]};
    
    %%%%%%%%%
    x=report.new('Historical Interpretation');
    
%     x.figure('Core Inflation',...
%         'style', st1, 'legend',true, 'range', rng);
% %     x.graph('Headline Inflation');
% %     x.series('QoQ @ar', d.DOTA_CPI);
% %     x.series('YoY', d.DOT4_CPI);
% %     x.highlight('', hglt);
%     x.graph('');
%     x.series('QoQ @ar', d.DOTA_CPIXFE);
%     x.series('YoY', d.DOT4_CPIXFE);
%     x.highlight('', hglt);
    
    
    %%%%%%%%%
    
    %% Overview
    x.figure('Overview','subplot',[2,2],...
        'style', st3, 'legend',false, 'range', rng);
    x.graph('Nominal Interest Rate (% p.a.)');
    x.series('', d.RS);
    x.highlight('', hglt);
    x.graph('Nominal Exchange Rate (LCY per 1 USD)');
    x.series('', d.S);
    x.highlight('', hglt);
    x.graph('Inflation (% YoY)','legend',true);
%     x.series('Headline', d.DOT4_CPI);
    x.series('Core', d.DOT4_CPIXFE);
    x.series('Target', d.DOT4_CPI_TAR);
    x.highlight('', hglt);
    x.graph('Real GDP Growth (% YoY)');
    x.series('', d.DOT4_GDP);
    x.highlight('', hglt);
    
    %% Gaps
    x.figure('Gaps', 'subplot',[2,2],...
        'style', st3, 'legend', false, 'range', rng);
    x.graph('Output Gap (%)','zeroline',true);
    x.highlight('', hglt);
    x.series('', d.L_GDP_GAP);
    x.graph('RER Gap (%)','legend',true,'zeroline',true);
    x.highlight('', hglt);
    x.series('Effective', d.L_REER_GAP);
    x.series('wrt. US',   d.L_Z_GAP);
    x.graph('1Y RIR Gap (%)','zeroline',true);
    x.series('', d.RR4_GAP);
    x.highlight('', hglt);
    x.graph('Short RIR Gap (%)','zeroline',true);
    x.series('', d.RR_GAP);
    x.highlight('', hglt);
    
    
    %% Trends
%     x.figure('Levels and Trends', 'subplot',[2,2],...
%         'style', st3, 'legend', false, 'range', rng);
%     x.graph('GDP (100*log)');
%     x.series('', d.L_GDP);
%     x.series('', d.L_GDP_BAR);
%     x.highlight('', hglt);
%     x.graph('Real Exchange Rate wrt US (100*log)');
%     x.series('', d.L_Z);
%     x.series('', d.L_Z_BAR);
%     x.highlight('', hglt);    
%     x.graph('1Y Real Interest Rate (100*log)');
%     x.series('', d.RR4);
%     x.series('', d.RR4_BAR);
%     x.highlight('', hglt);
%     x.graph('Real Exchange Rate wrt EZ (100*log)');
%     x.series('', d.L_Z_EUR);
%     x.series('', d.L_Z_BAR_EUR);
%     x.highlight('', hglt);
    
%     % growth
%     x.figure('Growth Rates with Trend Growth (dashed)', 'subplot',[2,2],...
%         'style', st3, 'legend', false, 'range', rng);
%     x.graph('GDP (%, YoY)');
%     x.series('', d.DOT4_GDP);
%     x.series('', d.DOT4_GDP_BAR);
%     x.highlight('', hglt);
%     x.graph('Real Exchange Rate (%, QoQ @ar)');
%     x.series('', d.DLA_Z);
%     x.series('', d.DLA_Z_BAR);
%     x.highlight('', hglt);
%     x.graph('GDP (%, QoQ @ar)');
%     x.series('', d.DOTA_GDP);
%     x.series('', d.DOTA_GDP_BAR);
%     x.highlight('', hglt);
%     x.graph('Headline Inflation and Target (%, YoY)');
%     x.series('', d.DOT4_CPI);
%     x.series('', d.DOT4_CPI_TAR);
%     x.highlight('', hglt);
%     
    
%     x.figure('Real Interest Rate', 'range', rng, 'legend', true, 'style', sto, 'subplot', [2,1]);
%     x.graph('1Y Real Interest rates', 'legendLocation', 'NW', 'style', st3);
%     x.series('1Y RIR', d.RR4);
%     x.series('1Y RIR Trend', d.RR4_BAR,'linestyle','--');
%     x.highlight('', hglt);
%     x.graph('Short Real Interest rates', 'legendLocation', 'NW', 'style', st3);
%     x.series('Short RIR', d.RR);
%     x.series('Short RIR Trend', d.RR_BAR,'linestyle','--');
%     x.highlight('', hglt);
    
    %% RER
    fh = figure('visible','off');
    subplot(221)
    p=plot(rng,[d.L_Z d.L_Z_BAR],'LineWidth',1.5);
    set(p,{'linestyle'},{'-';'--'});
    grid on
    title('Real Exchange Rate wrt US (100*log)');
    legend('Level','Trend');
    highlight(hglt);
    subplot(222)
    p=plot(rng,[d.L_REER_GAP d.L_Z_GAP],'LineWidth',1.5);
    set(p,{'linestyle'},{'-';'--'});
    grid on
    title('Real Exchange Rate Gap (percent)');
    legend('Effective','wrt USD');
    highlight(hglt);
    subplot(223)
    p=plot(rng,[d.L_Z_EUR d.L_Z_BAR_EUR],'LineWidth',1.5);
    set(p,{'linestyle'},{'-';'--'});
    grid on
    title('Real Exchange Rate wrt EUR (100*log)');
    legend('Level','Trend');
    highlight(hglt);
    subplot(224)
    p=plot(rng,[d.D4L_GDP d.D4L_GDP_BAR],'LineWidth',1.5);
    set(p,{'linestyle'},{'-';'--'});
    grid on
    title('Real GDP Growth (percent )');
    legend('Level','Trend');
    x.userfigure('Real Exchange Rate and GDP', fh);
   
    %% Nominal exchange rate
    fh = figure('visible','off');
    subplot(221)
    p=plot(rng, exp(d.L_S_EUR_UNC/100),'LineWidth',1.5);
    grid on
    title('Nominal Exchange Rate (CZK per EUR)');
    highlight(hglt);
    subplot(222)
    p=plot(rng, exp(d.L_S/100),'LineWidth',1.5);
    grid on
    title('Nominal Exchange Rate (CZK per USD)');
    highlight(hglt);
    subplot(223)
    p=plot(rng, [d.L_S_EUR_UNC d.L_S],'LineWidth',1.5);
    set(p,{'linestyle'},{'-';'-'});
    legend('wrt EUR','wrt USD');
    grid on
    title('Nominal Exchange Rate (100*log)');
    highlight(hglt);
    subplot(224)
    p=plot(rng, exp(d.L_S_EUR_UNC/100)/exp(d.L_S/100),'LineWidth',1.5);
    grid on
    title('Nominal Exchange Rate (USD per EUR)');
    highlight(hglt);
    x.userfigure('Nominal Exchange Rates', fh);

    
    %% Decompositions
    % IS curve
    fh = figure('visible','off');
    subplot(211);
      u = [d.b1*d.E1_L_GDP_GAP, d.b2*d.L_GDP_GAP{-1}, -d.b3*d.RR4_GAP{-1}, ...
          d.b4*d.L_REER_GAP{-1}, +d.b5*d.L_GDP_GAP_RW, ...
          + d.SHK_L_GDP_GAP];
      [upos, uneg] = posneg(u, rng);
      bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
      p = plot(rng, [d.L_GDP_GAP d.L_GDP_GAP],'LineWidth',1.5); grid on;
      set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
      legend('Forward','Backward','RIR gap', 'REER gap',...
          'Foreign Demand','Shock',...
          'location','Southoutside','orientation','horizontal');
      highlight(hglt);
    subplot(223);
      u = [d.exp_us*d.L_GDP_GAP_US, ...
          d.exp_eu*d.L_GDP_GAP_EU, ...
          d.exp_ja*d.L_GDP_GAP_JA, ...
          d.exp_ch*d.L_GDP_GAP_CH, ...
          d.exp_ea7*d.L_GDP_GAP_EA7, ...
          d.exp_la6*d.L_GDP_GAP_LA6, ...
          d.exp_rc6*d.L_GDP_GAP_RC6];
      [upos, uneg] = posneg(u, rng);
      bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
      p = plot(rng, [d.L_GDP_GAP_RW d.L_GDP_GAP_RW],'LineWidth',1.5); grid on;
      set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
      legend('US','EU','JA','CH','EA7','LA6','RC6',...
          'location','Southoutside','orientation','horizontal');
      title('Foreign Demand');
      highlight(hglt);
    subplot(224);
      u = [d.imp_us*d.L_Z_GAP, ...
          d.imp_eu*(d.L_Z_GAP-d.L_Z_GAP_EU), ...
          d.imp_ja*(d.L_Z_GAP-d.L_Z_GAP_JA), ...
          d.imp_ch*(d.L_Z_GAP-d.L_Z_GAP_CH), ...
          d.imp_ea7*(d.L_Z_GAP-d.L_Z_GAP_EA7), ...
          d.imp_la6*(d.L_Z_GAP-d.L_Z_GAP_LA6), ...
          d.imp_rc6*(d.L_Z_GAP-d.L_Z_GAP_RC6)];
      [upos, uneg] = posneg(u, rng);
      bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
      p = plot(rng, [d.L_REER_GAP d.L_REER_GAP],'LineWidth',1.5); grid on;
      set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
      legend('US','EU','JA','CH','EA7','LA6','RC6',...
          'location','Southoutside','orientation','horizontal');
      title('Real Effective Exchange Rate Gap');  
      highlight(hglt);    
    x.userfigure('Real Output Gap (%)', fh);
    
    % phillips curve
    fh = figure('visible','off');
    u = [d.a1*d.E4_D4L_CPIXFE, (1-d.a1)*d.D4L_CPIXFE{-1}, ...
        + d.a2*(d.DL_REER_GAP), ...
        + d.a3*d.L_REER_GAP, ...
        + d.a4*(d.L_QOIL_GAP+d.L_Z_GAP), ...
        + d.a5*(d.L_QFOOD_GAP+d.L_Z_GAP), ...
        + d.a6*(d.L_GDP_GAP{-1}), ...
        + d.SHK_DLA_CPIXFE];
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
    p = plot(rng, [d.DLA_CPIXFE d.DLA_CPIXFE]); grid on;
    set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
    legend('Exp.','Lag','Chng. in REER Gap','REER gap',...
        'Oil', 'Food','Y gap','Shock',...
        'location','Southoutside','orientation','horizontal');
    highlight(hglt);
    x.userfigure('Core Inflation Phillipse Curve (% QoQ @ar, log approx)', fh);
    
    % MP rule
    fh = figure('visible','off');
    u = [d.g1*d.RS{-1},...
        + (1-d.g1)*(d.RS_NEUTRAL), ...
        + (1-d.g1)*d.g2*(d.D4L_CPI_DEV), ...
        + (1-d.g1)*d.g4*d.L_GDP_GAP,...
        + d.SHK_RS];
    %       + (1-d.g1)*d.g3*d.E8_P_GAP,...
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
    p = plot(rng, [d.RS d.RS],'LineWidth',1.5); grid on;
    set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
    legend('Lag','Neutral','Inflation Deviation','Output Gap','Shock',...
        'location','Southoutside','orientation','horizontal');
    highlight(hglt);
    x.userfigure('Policy Rate (%, p.a.)', fh);
    
%     % UIP
%     fh = figure('visible','off');
%     u = [d.CTYPREM,...
%         d.c1_L_S*4*(d.E1_L_S-d.L_S),...
%         (1-d.c1_L_S)*(2*(d.DLA_Z_BAR-d.D4L_CPI_TAR_US+d.D4L_CPI_TAR)-d.DLA_S),...
%         4*d.SHK_L_S];
%     [upos, uneg] = posneg(u, rng);
%     bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
%     p = plot(rng, [d.RS-d.RS_US d.RS-d.RS_US],'LineWidth',1.5); grid on;
%     set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
%     legend('Long Premium','Exp. Deprec','Trend Deprec','UIP Shock',...
%         'location','Southoutside','orientation','horizontal');
%     highlight(hglt);
%     x.userfigure('Interest Rate Differencial (p.p., p.a.)', fh);
    
       
%     % foreign relative prices
%     x.figure('Real Price to respective CPI: Actual and Trend',...
%         'subplot', [2,1], 'style', st3, 'legend',false, 'range', rng);
%     %- real world energy price
%     x.graph('Real Oil Price World (100*log)');
%     x.series('', d.L_QOIL);
%     x.series('', d.L_QOIL_BAR);
%     x.highlight('', hglt);
%     %- real world food price
%     x.graph('Real Food Price World (100*log)');
%     x.series('', d.L_QFOOD);
%     x.series('', d.L_QFOOD_BAR);
%     x.highlight('', hglt);
%     
    %% Foreign variables
%     x.figure('Foreign Variables',...
%         'subplot', [2,3], 'style', st3, 'legend',false, 'range', rng);
%     x.graph('US Nominal Interest Rate (% p.a.)');
%     x.series('', d.RS_US);
%     x.highlight('', hglt);
%     x.graph('World Oil Price (USD)');
%     x.series('', exp(d.L_OIL/100));
%     x.highlight('', hglt);
%     x.graph('World Food Price (USD)');
%     x.series('', exp(d.L_FOOD/100));
%     x.highlight('', hglt);
%     x.graph('US Headline CPI Inflation (% YoY)');
%     x.series('', d.DOT4_CPI_US);
%     x.highlight('', hglt);
%     x.graph('Foreign Effective Real Output Gap (%)');
%     x.series('', d.L_GDP_GAP_RW);
%     x.highlight('', hglt);
%     x.graph('US Real Interest Rate Trend (% p.a.)');
%     x.series('', d.RR_BAR_US);
%     x.highlight('', hglt);
   
    
    %% Analytical graphs
    st4 = st1;
    st4.line.lineStyle = {'-','--','--','-.'};
    st4.line.Color = {[0,0,0.9],[0,0,0],[0.9,0,0],[0,0.5,0]};
    st4.line.Marker = {'none','none','none','none'};
    
    st5 = st1;
    st5.line.lineStyle = {'-','--','--','-.','-.'};
    st5.line.Color = {[0,0,0.9],[0,0,0],[0.9,0,0],[0,0.5,0],[0,0,0.5]};
    st5.line.Marker = {'none','none','none','none','none'};
    
    st8 = st1;
    st8.line.lineStyle = {'-','--','-','--','-','--','-','--'};
    st8.line.Color = {[0,0,0.9],'k','r','k',[0,0.5,0],'k',[0.9,0,0],'k'};
    st8.line.Marker = {'none','none','none','none','none'};
    
    styg = st1;
    styg.line.linewidth       = {2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4};
    styg.line.linestyle       = {'--','--','--','--','--','--','--','--','--','--','--','--','--','--','--','-'};
    nLines                    = 14;
    colPalette                = varycolor(nLines);
    styg.line.color           = {};
    for iter = 1:nLines
        styg.line.color{end+1}           = colPalette(iter,:);
    end
    
    list = {'y_gap13q01','y_gap13q02','y_gap13q03','y_gap13q04',...
        'y_gap14q01','y_gap14q02','y_gap14q03','y_gap14q04',...
        'y_gap15q01','y_gap15q02','infprog15q03','y_gap15q04',...
        'y_gap16q01','y_gap16q02','y_gap16q03'};
    
    %data transformation
    dq.ppi_agr    = convert(x12(dm.ppi_agr_su), 'q');
    dq.ppi_indust = convert(x12(dm.ppi_indust_su), 'q');
    dq.ppi_constr = convert(x12(dm.ppi_constr_su), 'q');
    dq.ppi_serv   = convert(x12(dm.ppi_serv_su), 'q');
    
    dq.l_ppi_agr    = 100*log(dq.ppi_agr);
    dq.l_ppi_indust = 100*log(dq.ppi_indust);
    dq.l_ppi_constr = 100*log(dq.ppi_constr);
    dq.l_ppi_serv    = 100*log(dq.ppi_serv);
    
    dq.wage_nom      = x12(dq.wage_nom_su);
    dq.l_wage_nom    = 100*log(dq.wage_nom);
    dq.l_wage_real_x = dq.l_wage_nom - d.L_CPIXFE;
    dq.l_wage_real   = dq.l_wage_nom - d.L_CPI;
    
    dq.l_wage_real_ppi_a = dq.l_wage_nom - dq.l_ppi_agr;
    dq.l_wage_real_ppi_i = dq.l_wage_nom - dq.l_ppi_indust;
    dq.l_wage_real_ppi_c = dq.l_wage_nom -dq.l_ppi_constr;
    dq.l_wage_real_ppi_s = dq.l_wage_nom -dq.l_ppi_serv;
    
    dq.l_rp_cpi_ppi_i      = d.L_CPI - dq.l_ppi_indust;
    dq.l_rp_cpi_ppi_c      = d.L_CPI - dq.l_ppi_constr;
    dq.l_rp_cpi_ppi_s      = d.L_CPI - dq.l_ppi_serv;
    
    [dq.l_wage_real_tnd dq.l_wage_real_gap] = hpf(dq.l_wage_real);
    [dq.l_wage_real_x_tnd dq.l_wage_real_x_gap] = hpf(dq.l_wage_real_x);
    
    [dq.l_wage_real_ppi_a_tnd dq.l_wage_real_ppi_a_gap] = hpf(dq.l_wage_real_ppi_a);
    [dq.l_wage_real_ppi_i_tnd dq.l_wage_real_ppi_i_gap] = hpf(dq.l_wage_real_ppi_i);
    [dq.l_wage_real_ppi_c_tnd dq.l_wage_real_ppi_c_gap] = hpf(dq.l_wage_real_ppi_c);
    [dq.l_wage_real_ppi_s_tnd dq.l_wage_real_ppi_s_gap] = hpf(dq.l_wage_real_ppi_s);
    
    [dq.l_rp_cpi_ppi_i_tnd dq.l_rp_cpi_ppi_i_gap] = hpf(dq.l_rp_cpi_ppi_i);
    [dq.l_rp_cpi_ppi_c_tnd dq.l_rp_cpi_ppi_c_gap] = hpf(dq.l_rp_cpi_ppi_c);
    [dq.l_rp_cpi_ppi_s_tnd dq.l_rp_cpi_ppi_s_gap] = hpf(dq.l_rp_cpi_ppi_s);
    
    %dq.wage_real_index   = x12(dq.wage_real_index_su);
    dq.l_wage_real_index = 100*log(dq.wage_real_index);
    [dq.l_wage_real_index_tnd dq.l_wage_real_index_gap] = hpf(dq.l_wage_real_index);
    
    dq.gdp_cons      = x12(dq.gdp_cons_su);
    dq.gdp_cons_hh   = x12(dq.gdp_cons_hh_su);
    dq.gdp_cons_gov  = x12(dq.gdp_cons_gov_su);
    dq.gdp_gfc       = x12(dq.gdp_gfc_su);
    
    dq.l_gdp_cons    = 100*log(dq.gdp_cons);
    dq.l_gdp_cons_hh    = 100*log(dq.gdp_cons_hh);
    dq.l_gdp_cons_gov    = 100*log(dq.gdp_cons_gov);
    dq.l_gdp_gfc       = 100*log(dq.gdp_gfc);
    
    [dq.l_gdp_cons_tnd dq.l_gdp_cons_gap] = hpf(dq.l_gdp_cons);
    [dq.l_gdp_cons_hh_tnd dq.l_gdp_cons_hh_gap] = hpf(dq.l_gdp_cons_hh);
    [dq.l_gdp_cons_gov_tnd dq.l_gdp_cons_gov_gap] = hpf(dq.l_gdp_cons_gov);
    [dq.l_gdp_gfc_tnd dq.l_gdp_gfc_gap] = hpf(dq.l_gdp_gfc);
    
    rng = qq(2000,1):qq(2016,3);
    
%     x.figure('Output gap comparison', 'subplot',[2, 1],...
%         'style', st4, 'legend', true ,'range', rng);
%     x.graph('Output Gap (%) OGR vs CNB (Inflation Report 16/I)','zeroline',true, 'legendLocation', 'NW');
%     x.series('Output gap OGR', d.L_GDP_GAP);
%     %x.series('Output gap CNB, production function', dq.output_gap_pf_1601);
%     x.series('Output gap CNB, kalman', dq.y_gap16q03);
%     %x.series('Output gap CNB, HPf', dq.output_gap_hp_1601);
%     x.graph('Output Gap (%) OGR vs OECD, IMF, EU-EC','zeroline',true, 'legendLocation', 'NW' ,'range', yy(1998,1):yy(2015,1));
%     x.series('Output gap OGR', convert(d.L_GDP_GAP, 'y'));
%     x.series('Output gap OECD, Nov 15', dy.output_gap_oecd_15);
%     x.series('Output gap IMF, Article IV', dy.output_gap_imf_15);
%     x.series('Output gap European Commission, 2016 Feb', dy.output_gap_ec_16);
    
    rng = qq(2005,1):qq(2018,4);
    x.figure('CNB: Estimation of the output gaps (%)', 'style',styg,'legend',true,'legendLocation=','NE','range',rng,'figurescale',0.7);
    x.graph('');
    x.series('2013Q01'     , dq.y_gap13q01);
    x.series('2013Q02'     , dq.y_gap13q02);
    x.series('2013Q03'     , dq.y_gap13q03);
    x.series('2013Q04'     , dq.y_gap13q04);
    x.series('2014Q01'     , dq.y_gap14q01);
    x.series('2014Q02'     , dq.y_gap14q02);
    x.series('2014Q03'     , dq.y_gap14q03);
    x.series('2014Q04'     , dq.y_gap14q04);
    x.series('2015Q01'     , dq.y_gap15q01);
    x.series('2015Q02'     , dq.y_gap15q02);
    x.series('2015Q03'     , dq.y_gap15q03);
    x.series('2015Q04'     , dq.y_gap15q04);
    x.series('2016Q01'     , dq.y_gap16q01);
    x.series('2016Q02'     , dq.y_gap16q02);
    x.series('2016Q03'     , dq.y_gap16q03);
    x.series('Model Output Gap'       , d.L_GDP_GAP);
    
    x.figure('GDP analysis I', 'subplot',[2, 1],...
        'style', st4, 'legend', true ,'range', rng);
    x.graph('Output Gap (%) vs Consumption (%, H-P filter)','zeroline',true, 'legendLocation', 'NW');
    x.series('Output gap OGR', d.L_GDP_GAP);
    x.series('Consumption gap', dq.l_gdp_cons_gap);
    x.series('Consumption gap (HH)', dq.l_gdp_cons_hh_gap);
    x.series('Consumption gap (Gov)', dq.l_gdp_cons_gov_gap);
    x.graph('Output Gap (%) vs Capital (%, H-P filter)','zeroline',true, 'legendLocation', 'NW');
    x.series('Output gap OGR', d.L_GDP_GAP);
    x.series('Gross Fix. capital gap', dq.l_gdp_gfc_gap);
    
    x.figure('Wage analysis', 'subplot',[2, 1],...
        'style', st4, 'legend', true ,'range', rng);
    x.graph('Output Gap (%) vs Real wage gap (%, H-P filter)','zeroline',true, 'legendLocation', 'NW');
    x.series('Output gap', d.L_GDP_GAP);
    x.series('Real wage gap, CPI', dq.l_wage_real_gap);
    x.series('Real wage gap, CPI-X', dq.l_wage_real_x_gap);
    x.series('Real wage gap, PPI ind', dq.l_wage_real_ppi_i_gap);
    x.graph('Real Wage (100*log, H-P filter)','legend',true,'zeroline',true, 'legendLocation', 'NW');
    x.series('CPI', dq.l_wage_real - dq.l_wage_real(qq(2000,1)));
    x.series('CPI tnd', dq.l_wage_real_tnd - dq.l_wage_real_tnd(qq(2000,1)));
    x.series('CPI-X', dq.l_wage_real_x - dq.l_wage_real_x(qq(2000,1)));
    x.series('CPI-X tnd', dq.l_wage_real_x_tnd - dq.l_wage_real_x_tnd(qq(2000,1)));
    
    x.figure('Wage analysis I', 'subplot',[2, 1],...
        'style', st4, 'legend', true ,'range', rng);
    x.graph('Inflation (%) vs Real wage gap (%, H-P filter)','zeroline',true, 'legendLocation', 'NW');
    x.series('QoQ', d.DLA_CPI);
    x.series('YoY', d.D4L_CPI);
    x.series('Real wage gap, CPI', dq.l_wage_real_gap);
    x.series('Real wage gap, PPI ind', dq.l_wage_real_ppi_i_gap);
    x.graph('Consumption (%, H-P filter) vs Real wage gap (%, H-P filter)','zeroline',true, 'legendLocation', 'NW');
    x.series('Consumption gap', dq.l_gdp_cons_gap);
    x.series('Real wage gap, CPI', dq.l_wage_real_gap);
    x.series('Real wage gap, PPI ind', dq.l_wage_real_ppi_i_gap);
    
    x.figure('Wage analysis II', 'subplot',[2, 1],...
        'style', st4, 'legend', true ,'range', rng);
    x.graph('Real wage gap (%, H-P filter)','zeroline',true, 'legendLocation', 'NW');
    x.series('Real wage gap, CPI', dq.l_wage_real_gap);
    x.series('Real wage gap, PPI ind', dq.l_wage_real_ppi_i_gap);
    x.series('Real wage gap, PPI constr', dq.l_wage_real_ppi_c_gap);
    x.series('Real wage gap, PPI ser', dq.l_wage_real_ppi_s_gap);
    x.graph('Real Wage (100*log, H-P filter)','zeroline',true, 'legendLocation', 'NW', 'range', qq(2005,1):qq(2016,1),...
        'style', st4);
    x.series('CPI', dq.l_wage_real - dq.l_wage_real(qq(2005,1)));
    x.series('PPI ind', dq.l_wage_real_ppi_i - dq.l_wage_real_ppi_i(qq(2005,1)));
    x.series('PPI constr', dq.l_wage_real_ppi_c - dq.l_wage_real_ppi_c(qq(2005,1)));
    x.series('PPI ser', dq.l_wage_real_ppi_s - dq.l_wage_real_ppi_s(qq(2005,1)));
    
    x.figure('Wage analysis III', 'subplot',[2, 1],...
        'style', st8, 'legend', true ,'range', rng);
    x.graph('Relative Prices CPI vs PPI (100*log, H-P filter)','zeroline',true, 'legendLocation', 'NW', 'range', qq(2000,1):qq(2016,1));
    x.series('ind', dq.l_rp_cpi_ppi_i - dq.l_rp_cpi_ppi_i(qq(2005,1)));
    x.series('constr', dq.l_rp_cpi_ppi_c - dq.l_rp_cpi_ppi_c(qq(2005,1)));
    x.series('serv', dq.l_rp_cpi_ppi_s - dq.l_rp_cpi_ppi_s(qq(2005,1)));
    x.graph('Relative Prices CPI vs PPI GAP (%, H-P filter)','zeroline',true, 'legendLocation', 'NW', 'range', qq(2000,1):qq(2016,1),...
        'style', st3);
    x.series('ind gap', dq.l_rp_cpi_ppi_i_gap);
    x.series('constr gap', dq.l_rp_cpi_ppi_c_gap);
    x.series('ser gap', dq.l_rp_cpi_ppi_s_gap);
    
%     x.figure('Okun''s Law', 'subplot',[2, 1],...
%         'style', st4, 'legend', true ,'range', rng);
%     x.graph('Unemployment (%) vs Real output gap (%)','zeroline',true, 'legendLocation', 'NW');
%     x.series('Unemployment gap (neg)', -d.UNR_GAP);
%     x.series('output gap', d.L_GDP_GAP);
%       x.graph('Consumption (%, H-P filter) vs Real wage gap (%, H-P filter)','zeroline',true, 'legendLocation', 'NW');
%       x.series('Consumption gap', dq.l_gdp_cons_gap);
%       x.series('Real wage gap, CPI', dq.l_wage_real_gap);
    
    f = figure('visible', 'off');
    subplot(211)
    [a, b, c] = plotyy(qq(2000,1):qq(2016,1), [d.L_GDP_GAP dq.l_wage_real_gap], qq(2000,1):qq(2016,1), [d.L_REER_GAP]);
    set(b,{'color'},{[0 0.5 0];'r'}, 'linewidth', 2);
    set(c,{'color'},{'b'},'linestyle','--', 'linewidth', 2);
    legend([b ; c],'Output gap OGR', 'Real wage gap, CPI', 'Effective REER GAP (RHS)', 'location', 'SW');grid
    subplot(212)
    p = plot(qq(2000,1):qq(2016,1), [d.L_GDP_GAP dq.l_wage_real_gap diff(dq.l_wage_nom,-4) diff(dq.l_wage_nom,-1)]);
    legend('Output gap OGR', 'Real wage gap, CPI', 'YoY Nominal Wage inflation', 'QoQ Nominal Wage inflation', ...
        'location', 'NW');
    title('Output gap (%) vs real wage gap (%, hpf) vs wage inflation (%)');grid
    set(p(2:4),'linestyle','--');
    set(p(1:4), 'linewidth', 2);
    x.userfigure('RMC analysis', f);
    
    % trend growth data
    dq.dl_wage_real_tnd = (dq.l_wage_real_tnd - dq.l_wage_real_tnd{-1})*4;
    dq.dl_wage_real     = (dq.l_wage_real - dq.l_wage_real{-1})*4;
    
    f = figure('visible', 'off');
    subplot(211);
    p = plot( yy(2000):yy(2015), [convert(d.DLA_GDP_BAR,'y') convert(dq.dl_wage_real_tnd,'y')], 'Linewidth',2);
    title('Comparison of potential growth and trend of real wage [HPf]')
    legend('dl\_y\_tnd','dl\_wg\_tnd');
    grid;
    subplot(212);
    p = plot( yy(2000):yy(2015), [convert(d.DLA_GDP,'y') convert(dq.dl_wage_real,'y')], 'Linewidth',2);
    title('Comparison of YoY GDP and real wage growth [HPf]')
    legend('d4l\_y','d4l\_wg');
    grid;
    x.userfigure('Trend Analysis', f);
    
    
    
    %% Make report (calls the function "reporthistory")
    
    x.publish(['results' filesep 'filter_report_' datestr(now,'yyyymmmdd_HHMMSS') '.pdf'], 'display', false);
    
    disp('Done!')
    
end

if doShockDecompReport
    disp('Shock Decomposition Report...');
    %% Make Shock decomposition report
    dout = smooth.mean;
    
    opt.histdecomp_variables = {...
        'DLA_CPIXFE', 'D4L_CPIXFE', 'DLA_CPI', 'D4L_CPI',...
        'D4L_GDP', 'DLA_GDP','L_GDP_GAP',...
        'RS'};
    opt.histdecomp_groups = {...
        {'Initial conditions'}, ...
        {'SHK_DLA_CPIXFE','SHK_L_RP_GAP'},...
        {'SHK_L_GDP_GAP'},...
        {'SHK_L_S'},...
        {'SHK_L_QOIL_GAP','SHK_L_QFOOD_GAP','SHK_DLA_QOIL_BAR','SHK_DLA_QFOOD_BAR'},...
        {'SHK_L_GDP_GAP_US','SHK_DLA_GDP_BAR_US','SHK_DLA_CPI_US','SHK_DLA_CPIXFE_US','SHK_RS_US','SHK_RR_BAR_US'},...
        {'SHK_L_GDP_GAP_EU', 'SHK_L_GDP_GAP_JA','SHK_L_GDP_GAP_CH', 'SHK_L_GDP_GAP_EA7','SHK_L_GDP_GAP_LA6', 'SHK_L_GDP_GAP_RC6'},...
        {'SHK_RS', 'SHK_D4L_CPI_TAR'},...
        {'SHK_DLA_GDP_BAR','SHK_DLA_RP_BAR','SHK_L_Z_BAR','SHK_RR_BAR'},...
        {'SHK_DLA_QOIL_BAR','SHK_L_QOIL_GAP','SHKA_L_QOIL_GAP','SHK_DLA_QFOOD_BAR','SHK_L_QFOOD_GAP'}};
    opt.histdecomp_grnames = {...
        'Initial Conditions',...
        'Supply Shocks',...
        'Demand Shocks',...
        'UIP Shocks',...
        'Commodity Price Shocks', ...
        'U.S. Shocks',...
        'Foreign Demand Shocks',...
        'MP Shocks',...
        'Trends',...
        'Commodity price Shocks'};
    %%% zjistit co znamena rest
    opt.histdecomp_range = qq(2000,1):edate;
    
    [f fighs] = decomp_shocks(m, dout, opt.histdecomp_range,...
        opt.histdecomp_variables,...
        opt.histdecomp_groups,...
        opt.histdecomp_grnames);
    
    x = report.new('Historical shock decomposition report');
    cm = get(m, 'comments');
    for ind = 1:length(fighs)
        var = opt.histdecomp_variables{ind};
        tit = ['Shock decomposition of ' var ' (' cm.(var) ')'];
        x.userfigure(tit, fighs{ind});
    end
    x.publish(['results' filesep 'shock_decomp_' datestr(now,'yyyymmmdd_HHMMSS') '.pdf'], 'display', false);
    
    disp('Done!')
end

rmpath('results');
rmpath('utils');
