%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%% Forecasting %%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; close all; clc
disp('Forecasting ....')

% load model and filtered data
load results/model.mat
load results/filterdata.mat;


initdb = dbclip(d, starthist:endhist);
%% -----Forecasting round----- %
% External sector projection imposed, anchoring NTF for the nearest future

%% 1] specification of the variables to be anchored and the residuals to be 
%    computed to replicate the anchored variables

%%%%%%%%%%%%%%%%%%BEGINNING OF TUNINING%%%%%%%%%%%%%%%%%%%%%%%%%%
p = plan(m,endhist+1:endhist+30);

dbtunes = struct();
%% NTF and tunes for domestic variables
% NTF slight increase in cpi explained by core inflation and non-core
% drivers, yoy total inflation about 1.0, CNB has 1.2
% dbtunes.SHK_L_RP_GAP   = tseries();
% dbtunes.SHK_L_RP_GAP(qq(2016,4):qq(2017,1)) = [-0.1 -0.05];

% shock related to faster recovery in core inflation - expectations of
% agents, fast pass-through
dbtunes.SHK_DLA_CPIXFE = tseries();
dbtunes.SHK_DLA_CPIXFE(qq(2016,4):qq(2017,2)) = [0.3 0.2 0.1];

% election related inflation pressures
dbtunes.SHK_L_GDP_GAP = tseries();
dbtunes.SHK_L_GDP_GAP(qq(2017,3):qq(2018,1)) = [0.2 0.15 0.07];
dbtunes.SHK_DLA_CPIXFE(qq(2017,3):qq(2017,4)) = [0.2 0.2];

% the interest rates will not be negative as in EZ
dbtunes.RS = tseries();
dbtunes.RS(qq(2016,4):qq(2017,4)) = d.OBS_RS(qq(2016,3)); 
p = exogenize(p,{'RS'},qq(2016,4):qq(2017,4));
p = endogenize(p,{'SHK_RS'},qq(2016,4):qq(2017,4));

% the exchange rate peg will be followed until 2017q2 based on recent news
% coming from CNB analysis
% dbtunes.L_S_EUR_UNC = tseries();
% dbtunes.L_S_EUR_UNC(qq(2016,4):qq(2017,4)) = 100*log([27 27 26.7 26.5 26.2]);
% p = exogenize(p,{'L_S_EUR_UNC'},qq(2016,4):qq(2017,4));
% p = endogenize(p,{'SHK_L_S'},qq(2016,4):qq(2017,4));

dbtunes.D4L_CPI_TAR = tseries();
dbtunes.D4L_CPI_TAR(qq(2016,4):qq(2020,1)) = 100*log(1+2/100);
p = exogenize( p,{'D4L_CPI_TAR'},qq(2016,4):qq(2020,1));
p = endogenize(p,{'SHK_D4L_CPI_TAR'},qq(2016,4):qq(2020,1));

% dbtunes.CTYPREM = tseries();
% dbtunes.CTYPREM(qq(2016,4):qq(2018,3)) = -1;
% p = exogenize( p,{'CTYPREM'},qq(2016,4):qq(2018,3));
% p = endogenize(p,{'SHK_RR_BAR'},qq(2016,4):qq(2018,3));

dbtunes.DLA_Z_BAR_EUR = tseries();
dbtunes.DLA_Z_BAR_EUR(qq(2016,4):qq(2018,3)) = [0];
p = exogenize( p,{'DLA_Z_BAR_EUR'},qq(2016,4):qq(2018,3));
p = endogenize(p,{'SHK_DLA_Z_BAR'},qq(2016,4):qq(2018,3));

%% external variables

dbtunes.L_S_USD_EUR = tseries();
dbtunes.L_S_USD_EUR(qq(2016,4):qq(2018,3)) = 100*log([1.1172 1.11 1.10 1.10 1.10 1.10 1.10 1.10]);
p = exogenize(p,{'L_S_USD_EUR'},qq(2016,4):qq(2018,3));
p = endogenize(p,{'SHK_DLA_S_USD_EUR'},qq(2016,4):qq(2018,3));

dbtunes.RS_US = tseries();
dbtunes.RS_US = dObs.OBS_RS_US;
p = exogenize(p,{'RS_US'},endhist+1:get(dObs.OBS_RS_US,'last'));
p = endogenize(p,{'SHK_RS_US'},endhist+1:get(dObs.OBS_RS_US,'last'));

dbtunes.L_CPIXFE_US = tseries();
dbtunes.L_CPIXFE_US = dObs.OBS_L_CPIXFE_US;
p = exogenize(p,{'L_CPIXFE_US'},endhist+1:get(dObs.OBS_L_CPIXFE_US,'last'));
p = endogenize(p,{'SHK_DLA_CPIXFE_US'},endhist+1:get(dObs.OBS_L_CPIXFE_US,'last'));

dbtunes.L_CPI_US = tseries();
dbtunes.L_CPI_US = dObs.OBS_L_CPI_US;
p = exogenize(p,{'L_CPI_US'},endhist+1:get(dObs.OBS_L_CPI_US,'last'));
p = endogenize(p,{'SHK_DLA_CPI_US'},endhist+1:get(dObs.OBS_L_CPI_US,'last'));

dbtunes.L_GDP_US = tseries();
dbtunes.L_GDP_US = dObs.OBS_L_GDP_US;
p = exogenize(p,{'L_GDP_US'},endhist+1:get(dObs.OBS_L_GDP_US,'last'));
p = endogenize(p,{'SHK_L_GDP_GAP_US'},endhist+1:get(dObs.OBS_L_GDP_US,'last'));

dbtunes.RR_BAR_US = tseries();
dbtunes.RR_BAR_US = dObs.OBS_RR_BAR_US;
p = exogenize(p,{'RR_BAR_US'},endhist+1:get(dObs.OBS_RR_BAR_US,'last'));
p = endogenize(p,{'SHK_RR_BAR_US'},endhist+1:get(dObs.OBS_RR_BAR_US,'last'));

dbtunes.L_OIL = tseries();
dbtunes.L_OIL = dObs.OBS_L_OIL;
p = exogenize(p,{'L_OIL'},endhist+1:get(dObs.OBS_L_OIL,'last'));
p = endogenize(p,{'SHK_L_QOIL_GAP'},endhist+1:get(dObs.OBS_L_OIL,'last'));

dbtunes.L_FOOD = tseries();
dbtunes.L_FOOD = dObs.OBS_L_FOOD;
p = exogenize(p,{'L_FOOD'},endhist+1:get(dObs.OBS_L_FOOD,'last'));
p = endogenize(p,{'SHK_L_QFOOD_GAP'},endhist+1:get(dObs.OBS_L_FOOD,'last'));

dbtunes.DLA_QOIL_BAR = tseries();
dbtunes.DLA_QOIL_BAR = dObs.OBS_DLA_QOIL_BAR;
p = exogenize(p,{'DLA_QOIL_BAR'},endhist+1:get(dObs.OBS_DLA_QOIL_BAR,'last'));
p = endogenize(p,{'SHK_DLA_QOIL_BAR'},endhist+1:get(dObs.OBS_DLA_QOIL_BAR,'last'));

dbtunes.DLA_QFOOD_BAR = tseries();
dbtunes.DLA_QFOOD_BAR = dObs.OBS_DLA_QFOOD_BAR;
p = exogenize(p,{'DLA_QFOOD_BAR'},endhist+1:get(dObs.OBS_DLA_QFOOD_BAR,'last'));
p = endogenize(p,{'SHK_DLA_QFOOD_BAR'},endhist+1:get(dObs.OBS_DLA_QFOOD_BAR,'last'));

dbtunes.L_GDP_GAP_CH = tseries();
dbtunes.L_GDP_GAP_CH = dObs.OBS_L_GDP_GAP_CH;
p = exogenize(p,{'L_GDP_GAP_CH'},endhist+1:get(dObs.OBS_L_GDP_GAP_CH,'last'));
p = endogenize(p,{'SHK_L_GDP_GAP_CH'},endhist+1:get(dObs.OBS_L_GDP_GAP_CH,'last'));

dbtunes.L_GDP_GAP_EA7 = tseries();
dbtunes.L_GDP_GAP_EA7 = dObs.OBS_L_GDP_GAP_EA7;
p = exogenize(p,{'L_GDP_GAP_EA7'},endhist+1:get(dObs.OBS_L_GDP_GAP_EA7,'last'));
p = endogenize(p,{'SHK_L_GDP_GAP_EA7'},endhist+1:get(dObs.OBS_L_GDP_GAP_EA7,'last'));

dbtunes.L_GDP_GAP_EU = tseries();
dbtunes.L_GDP_GAP_EU = dObs.OBS_L_GDP_GAP_EU;
p = exogenize(p,{'L_GDP_GAP_EU'},endhist+1:get(dObs.OBS_L_GDP_GAP_EU,'last'));
p = endogenize(p,{'SHK_L_GDP_GAP_EU'},endhist+1:get(dObs.OBS_L_GDP_GAP_EU,'last'));

dbtunes.L_GDP_GAP_JA = tseries();
dbtunes.L_GDP_GAP_JA = dObs.OBS_L_GDP_GAP_JA;
p = exogenize(p,{'L_GDP_GAP_JA'},endhist+1:get(dObs.OBS_L_GDP_GAP_JA,'last'));
p = endogenize(p,{'SHK_L_GDP_GAP_JA'},endhist+1:get(dObs.OBS_L_GDP_GAP_JA,'last'));

dbtunes.L_GDP_GAP_LA6 = tseries();
dbtunes.L_GDP_GAP_LA6 = dObs.OBS_L_GDP_GAP_LA6;
p = exogenize(p,{'L_GDP_GAP_LA6'},endhist+1:get(dObs.OBS_L_GDP_GAP_LA6,'last'));
p = endogenize(p,{'SHK_L_GDP_GAP_LA6'},endhist+1:get(dObs.OBS_L_GDP_GAP_LA6,'last'));

dbtunes.L_GDP_GAP_RC6 = tseries();
dbtunes.L_GDP_GAP_RC6 = dObs.OBS_L_GDP_GAP_RC6;
p = exogenize(p,{'L_GDP_GAP_RC6'},endhist+1:get(dObs.OBS_L_GDP_GAP_RC6,'last'));
p = endogenize(p,{'SHK_L_GDP_GAP_RC6'},endhist+1:get(dObs.OBS_L_GDP_GAP_RC6,'last'));

dbtunes.L_Z_GAP_CH = tseries();
dbtunes.L_Z_GAP_CH = dObs.OBS_L_Z_GAP_CH;
p = exogenize(p,{'L_Z_GAP_CH'},endhist+1:get(dObs.OBS_L_Z_GAP_CH,'last'));
p = endogenize(p,{'SHK_L_Z_GAP_CH'},endhist+1:get(dObs.OBS_L_Z_GAP_CH,'last'));

dbtunes.L_Z_GAP_EA7 = tseries();
dbtunes.L_Z_GAP_EA7 = dObs.OBS_L_Z_GAP_EA7;
p = exogenize(p,{'L_Z_GAP_EA7'},endhist+1:get(dObs.OBS_L_Z_GAP_EA7,'last'));
p = endogenize(p,{'SHK_L_Z_GAP_EA7'},endhist+1:get(dObs.OBS_L_Z_GAP_EA7,'last'));

dbtunes.L_Z_GAP_EU = tseries();
dbtunes.L_Z_GAP_EU = dObs.OBS_L_Z_GAP_EU;
p = exogenize(p,{'L_Z_GAP_EU'},endhist+1:get(dObs.OBS_L_Z_GAP_EU,'last'));
p = endogenize(p,{'SHK_L_Z_GAP_EU'},endhist+1:get(dObs.OBS_L_Z_GAP_EU,'last'));

dbtunes.L_Z_GAP_JA = tseries();
dbtunes.L_Z_GAP_JA = dObs.OBS_L_Z_GAP_JA;
p = exogenize(p,{'L_Z_GAP_JA'},endhist+1:get(dObs.OBS_L_Z_GAP_JA,'last'));
p = endogenize(p,{'SHK_L_Z_GAP_JA'},endhist+1:get(dObs.OBS_L_Z_GAP_JA,'last'));

dbtunes.L_Z_GAP_LA6 = tseries();
dbtunes.L_Z_GAP_LA6 = dObs.OBS_L_Z_GAP_LA6;
p = exogenize(p,{'L_Z_GAP_LA6'},endhist+1:get(dObs.OBS_L_Z_GAP_LA6,'last'));
p = endogenize(p,{'SHK_L_Z_GAP_LA6'},endhist+1:get(dObs.OBS_L_Z_GAP_LA6,'last'));

dbtunes.L_Z_GAP_RC6 = tseries();
dbtunes.L_Z_GAP_RC6 = dObs.OBS_L_Z_GAP_RC6;
p = exogenize(p,{'L_Z_GAP_RC6'},endhist+1:get(dObs.OBS_L_Z_GAP_RC6,'last'));
p = endogenize(p,{'SHK_L_Z_GAP_RC6'},endhist+1:get(dObs.OBS_L_Z_GAP_RC6,'last'));

initdb = dbextend(dbtunes,initdb);

%% 3] running the forecast

Fm = simulate(m, initdb, endhist+1:endhist+20, 'plan', p,'anticipate', false,'nonlinear',20);
Fm = dboverlay(d,Fm);

initdb_std = dbclip(d, starthist:endhist);
Fm_std = jforecast(m, initdb_std, endhist+1:endhist+20, 'anticipate', true);

Fm_std = dbextend(d_std, Fm_std.std);

% for displaying tunes on forecast
tunes = get(p,'endogenised=');

%% 4] data storage
%save forecast.mat Fflex Fmng;

save results/forecast.mat Fm;
dbsave(Fm,'results/forecast.csv');

plotrng     = endhist-6 : endhist+8;
tablerng    = endhist-1 : endhist+8;
fcstrng     = endhist+1 : endhist+8;

% reportforecast;
reportforecast(m, Fm,'FORECASTING ROUND',plotrng, tablerng, fcstrng, tunes, dbtunes,['forecast_report_' datestr(now,'yyyymmmdd_HHMMSS')]);
disp('Done!')
