function P = cz_set_param(s)
  
P = struct();

%% Steady states
% Domestic
P.ss_D4L_CPI_TAR    = 2.0;
P.ss_DLA_GDP_BAR    = 2.0; 
P.ss_DLA_Z_BAR      = 0; %>>>
P.ss_CTYPREM        = 1; 
P.ss_RR_BAR         = -1;
P.ss_CTYPREM        =  -P.ss_DLA_Z_BAR + P.ss_RR_BAR - 1.88 ;

%% Business cycle
% IS Curve
P.b1     = 0.05;  % lead (calibrated)
P.b2     = 0.65;  % lag (OLS estimated)
P.b3     = 0.1;0.15;0.30;  % RR4_GAP (calibrated)
P.b4     = 0.05;  % L_REER_GAP (calibrated)
P.b5     = 0.30;  % foreign demand 
P.b6     = 0.5;   % terms of trade

% PC   
P.a1 = 0.75;0.85;      % lead (calibrated)
P.a2 = 0.005;0.2;0.04;0.05;0.05;      % imported (DL_Z_GAP)
P.a3 = 0.001;0.2;0.04;0.05;0.05;      % zgap
P.a4 = 0.005;      % L_QOIL_GAP
P.a5 = 0.005;      % L_QFOOD_GAP
P.a6 = 0.13;0.25;0.15;0.25;       % ygap (calibrated)

% UIP
P.c1_L_S      = 0.84; % (ToTEM)

% Interest equations 
P.g1    = 0.9;0.8;0.9;0.5;0.75;    % lag
P.g2    = 1.5;0.5;0.5;3;1.5;     % inflation 
%P.g3    = 0;%>>0.3;     % P_GAP
P.g4    = 0.2;0.2;0.5;     % L_GDP_GAP 

% ZLB
P.rs_floor = 0.05;
if s.dozlb
    P.nlrsswitch = 1;
else
    P.nlrsswitch = 0;
end

% Persistence paramters
P.rho_D4L_CPI_TAR    = 0.96;0.997;0.001;
P.rho_DLA_GDP_BAR    = 0.97; 
P.rho_CTYPREM        = 0.95;0.9;0.95; 
P.rho_DLA_Z_BAR      = 0.85;0.95; %>>>
P.rho_RR_BAR         = 0.8;0.7;0.9;0.7;0.001;0.95;0.001;0.95;

P.rho_DLA_S_USD_EUR = 0.9;

if s.optimrule == true 
    P.w_D4L_CPIXFE_DEV = 1.00;
    P.w_L_GDP_GAP      = 1.00;
    P.w_P_GAP          = 0;%>>1;
    P.w_RS             = 0.50;
    P.disc             = 0.98;    
end

%% standard errors
P.std_SHK_L_GDP_GAP  = 0.4;0.5;  
P.std_SHK_UNR_GAP    = 0.5*0.5; 
P.std_SHK_NAIRU      = 0.5*0.05;
P.std_SHK_D_NAIRU    = 0.5*0.05;
P.std_SHK_DLA_CPIXFE = 0.6;
P.std_SHK_L_RP_GAP   = 0.4;
P.std_SHK_L_S        = 2;
P.std_SHK_RS         = 0.3;0.5;

P.std_SHK_DLA_RP_BAR     = 0.1;
P.std_SHK_D4L_CPI_TAR    = 0.2;
P.std_SHK_DLA_GDP_BAR    = 0.15;0.2;0.35;0.25;
P.std_SHK_DLA_Z_BAR      = 0.6;0.22;0.3;
P.std_SHK_CTYPREM        = 0.05;0.1;0.1;0.4;0.6;0.2;0.3;
P.std_SHK_RR_BAR         = 0.5;0.0;0.0;0.5;1;0.2;
P.std_SHK_DLA_S_USD_EUR  = 0.1;

%% starting points for ss search
P.RS = P.ss_CTYPREM + P.ss_DLA_Z_BAR + 1.88 + P.ss_D4L_CPI_TAR; % initialize RS above ZLB, otherwise it picks wrong steady state
P.RS_UNC = P.RS;
P.DLA_CPIXFE = P.ss_D4L_CPI_TAR;
P.DLA_S = P.ss_DLA_Z_BAR - 2.5 + P.DLA_CPIXFE;
end
