function reportforecast(m, d,Heading, Plotrng, Tablerng, fcstrng, plan, tunes, fName)
disp('Reporting ...')

defstyle = struct;
defstyle.line.lineWidth = 2;
style1 = defstyle;
style1.line.marker = {'none','x'};
style1.line.lineStyle = {'-','none'};
barstyle = defstyle;
barstyle.line.lineWidth = {3,1.5};
barstyle.line.lineStyle = {'-','-','-','--'};
barstyle.line.color = {[1 1 1],[0 0 0],[1 1 1],[1 0 0]};
barstyle.legend.orientation = 'horizontal';
barstyle.legend.location = 'northoutside';
style2 = defstyle;
style2.legend.orientation = 'vertical';
style2.legend.location = 'eastOutside';
style2.legend.interpreter = 'none';


rep = report.new(Heading,'dateformat','YYYY:P');
addpath('utils');

d.CPIXFE     = exp(d.L_CPIXFE/100);
d.D4_CPI_TAR = 100*exp(d.D4L_CPI_TAR/100)-100;
d.GDP        = exp(d.L_GDP/100);
d.OIL        = exp(d.L_OIL/100);
d.FOOD       = exp(d.L_FOOD/100);

% external
d.CPIXFE_US = exp(d.L_CPIXFE_US/100);
d.CPI_US    = exp(d.L_CPI_US/100);
d.CPIXFE_EZ = exp(d.L_CPIXFE_EZ/100);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% page 1
rep.table('Table: Main Indicators','range',Tablerng,'vline',fcstrng(1)-1,'decimal',1);
 
  rep.series('Core CPI Inflation',pct(d.CPIXFE,-4),'units','% y-o-y','bold',true);
  rep.series('Core CPI Inflation',((d.CPIXFE/d.CPIXFE{-1})^4)*100-100,'units','% q-o-q, @ar');
  rep.series('Implied Inflation Target',d.D4_CPI_TAR,'units','% y-o-y','bold',true);
  rep.series('Policy Rate',d.RS,'units','%PA','bold',true,'decimal',2);
  rep.subheading('');
  rep.series('CZK per EUR', exp(d.L_S_EUR/100),'units','level','bold',true);
  rep.series('CZK per USD', exp(d.L_S/100),'units','level','bold',true);
  rep.series('EUR per USD', exp(d.L_S_USD_EUR/100), 'units', 'level','bold',true,'decimal',2);
 
  rep.subheading('');
  
  rep.subheading('Real economic activity','bold',true);
  rep.series('Output Growth',pct(d.GDP,-4),'units','% y-o-y','bold',false);
  rep.series('Output Growth',((d.GDP/d.GDP{-1})^4)*100-100,'units','% q-o-q @ar','bold',false);
  rep.series('Potential Output Growth',diff(d.L_GDP_BAR,-4),'units','% y-o-y','bold',false);
  rep.series('Output Gap',d.L_GDP_GAP,'units','%','bold',false);

  rep.subheading('');

  rep.subheading('Fundamentals','bold',true);
  rep.series('Real exchange rate gap, wrt EUR',d.L_Z_GAP_EUR,'units','%');
  rep.series('Real exchange rate gap, wrt USD',d.L_Z_GAP,'units','%');
  rep.series('Real interest rate gap',d.RR_GAP,'units','%');

  %% page 2
  rep.table('Table: Decomposition','range',Tablerng,'vline',fcstrng(1)-1,'decimal',2);
  
  rep.subheading('');

  rep.subheading('Real economic activity','bold',true);
  rep.series('Output Gap',d.L_GDP_GAP,'units','%','bold',false);
  rep.series('Lag',d.b2*d.L_GDP_GAP{-1},'units','PP');
  rep.series('Exp',d.b1*d.L_GDP_GAP{+1},'units','PP');
  rep.series('RIR gap',-d.b3*d.RR4_GAP{-1},'units','PP');
  rep.series('REER gap',d.b4*d.L_REER_GAP{-1},'units','PP');
  rep.series('Foreign Gap',d.b5*d.L_GDP_GAP_RW,'units','PP');
  rep.series('Residual',d.SHK_L_GDP_GAP,'units','PP');
  
  rep.subheading('');
 
  rep.subheading('Core CPI Inflation in log approx','bold',true);
  rep.series('Inflation'             ,d.DLA_CPIXFE               ,'units','% q-o-q','bold',true);
  rep.series('Lag'                   ,(1-d.a1)*(d.D4L_CPIXFE{-1}),'units','PP');
  rep.series('Expectations (+4q yoy)',d.a1*(d.D4L_CPIXFE{+4}),'units','PP');
  rep.series('REER GAP, QoQ'         ,d.a2*d.DL_REER_GAP,'units','PP');
  rep.series('REER GAP, level'       ,d.a3*d.L_REER_GAP,'units','PP');
  rep.series('Oil prices, level'     ,d.a4*(d.L_QOIL_GAP+d.L_Z_GAP),'units','PP');
  rep.series('Food prices, level'    ,d.a5*(d.L_QFOOD_GAP+d.L_Z_GAP),'units','PP');
  rep.series('Demand factors'        ,d.a6*d.L_GDP_GAP{-1},'units','PP');
  rep.series('Residuals'             ,d.SHK_DLA_CPIXFE,'units','PP');
  
  rep.subheading('');
  
  rep.subheading('Policy Rate','bold',true);
  rep.series('Policy Rate',d.RS_UNC,'units','%PA','bold',true);
  rep.series('Lag',d.g1*d.RS{-1},'units','PP');
  rep.series('Neutral Rate',(1-d.g1)*(d.RS_NEUTRAL),'units','PP');
  rep.series('Inflation Deviation',(1-d.g1)*(d.g2*d.D4L_CPI_DEV),...
      'units','PP');
  rep.series('Output gap',(1-d.g1)*(d.g4*d.L_GDP_GAP),'units','PP');
  rep.series('Residuals',d.SHK_RS,'units','PP');  
  
  rep.subheading('');
  
  rep.subheading('Nominal UIP','bold',true);
  rep.series('Exp. depr.',(d.EW_L_S-d.L_S)*4,'units','PP','bold',true);
  rep.series('Policy Rate',d.RS,'units','%PA');
  rep.series('US Rate',-d.RS_US,'units','%PA');
  rep.series('Premia',-d.CTYPREM,'units','PP');
  rep.series('Residuals',- d.SHK_L_S*4,'units','PP'); 
  %% page 3
 
rep.table('Table: External variables','range',Tablerng,'vline',fcstrng(1)-1,'decimal',1);

  rep.subheading('External Sector: Eurozone','bold', true);
  rep.series('US Inflation', pct(d.CPI_US,-4),'units','% y-o-y');
  rep.series('US Core Inflation', pct(d.CPIXFE_US,-4),'units','% y-o-y');
  rep.series('US Core Inflation', 4*diff(d.L_CPIXFE_US,-1),'units','% q-o-q @ar, log');
  rep.series('EZ Core Inflation', pct(d.CPIXFE_EZ,-4),'units','% y-o-y');
  rep.series('EZ Core Inflation', 4*diff(d.L_CPIXFE_EZ,-1),'units','% q-o-q @ar, log');
  rep.series('US Interest Rates', d.RS_US,'units','%PA');
  rep.series('US Output Gap', d.L_GDP_GAP_US,'units','%');
  rep.series('EZ Output Gap', d.L_GDP_GAP_EU,'units','%');
  
  rep.subheading('');
 
  rep.subheading('External Sector: Effective GDP Gap','bold', true);
  rep.series('Effective GDP Gap',d.L_GDP_GAP_RW,'units','PP');
  rep.series('US GDP Gap',d.exp_us*d.L_GDP_GAP_US,'units','PP');
  rep.series('EZ GDP Gap',d.exp_eu*d.L_GDP_GAP_EU,'units','PP');
  rep.series('JA GDP Gap',d.exp_ja*d.L_GDP_GAP_JA,'units','PP');
  rep.series('CH GDP Gap',d.exp_ch*d.L_GDP_GAP_CH,'units','PP');
  rep.series('EA7 GDP Gap',d.exp_ea7*d.L_GDP_GAP_EA7,'units','PP');
  rep.series('LA6 GDP Gap',d.exp_la6*d.L_GDP_GAP_LA6,'units','PP');
  rep.series('RC6 GDP Gap',d.exp_rc6*d.L_GDP_GAP_RC6,'units','PP');
  
  rep.subheading('');
  
  rep.subheading('External Sector: Effective REER Gap','bold', true);
  rep.series('Effective GDP Gap',d.L_REER_GAP,'units','PP');
  rep.series('US GDP Gap',d.trade_us*d.L_Z_GAP,'units','PP');
  rep.series('EZ GDP Gap',d.trade_eu*(d.L_Z_GAP-d.L_Z_GAP_EU),'units','PP');
  rep.series('JA GDP Gap',d.trade_ja*(d.L_Z_GAP-d.L_Z_GAP_JA),'units','PP');
  rep.series('CH GDP Gap',d.trade_ch*(d.L_Z_GAP-d.L_Z_GAP_CH),'units','PP');
  rep.series('EA7 GDP Gap',d.trade_ea7*(d.L_Z_GAP-d.L_Z_GAP_EA7),'units','PP');
  rep.series('LA6 GDP Gap',d.trade_la6*(d.L_Z_GAP-d.L_Z_GAP_LA6),'units','PP');
  rep.series('RC6 GDP Gap',d.trade_rc6*(d.L_Z_GAP-d.L_Z_GAP_RC6),'units','PP');
        
  rep.subheading('');
  
  rep.subheading('External Sector: Commodities','bold', true);
  rep.series('Brent Oil Price', d.OIL,'units','USD per barrel');
  rep.series('FAO Food Price',d.FOOD,'units','USD Index');
  
  rep.table('Table: Identities','range',Tablerng,'vline',fcstrng(1)-1,'decimal',1);
  
  rep.subheading('');
  
  rep.subheading('RER CZ/US decomp, QoQ @ar','bold', true);
  rep.series('RER',d.DLA_Z,'units','PP');
  rep.series('RER GAP',(d.L_Z_GAP-d.L_Z_GAP{-1})*4,'units','PP');
  rep.series('RER TND',d.DLA_Z_BAR,'units','PP');
  
  rep.subheading('');
  
  rep.subheading('RER CZ/US decomp, QoQ @ar','bold', true);
  rep.series('RER',(d.L_Z-d.L_Z{-1})*4,'units','PP');
  rep.series('CZK per USD',(d.L_S-d.L_S{-1})*4,'units','PP');
  rep.series('Domestic Core inflation',-(d.L_CPIXFE-d.L_CPIXFE{-1})*4,'units','PP');
  rep.series('US core inflation',(d.L_CPIXFE_US-d.L_CPIXFE_US{-1})*4,'units','PP');
  
  rep.subheading('');
  
  rep.subheading('RER CZ/EZ decomp, QoQ @ar','bold', true);
  rep.series('RER',(d.L_Z_EUR-d.L_Z_EUR{-1})*4,'units','PP');
  rep.series('RER CZ/US GAP',(d.L_Z_GAP-d.L_Z_GAP{-1})*4,'units','PP');
  rep.series('RER US/EU',-(d.L_Z_GAP_EU-d.L_Z_GAP_EU{-1})*4,'units','PP');
  rep.series('RER TND',d.DLA_Z_BAR_EUR,'units','PP');
  
  rep.subheading('');
  
  rep.subheading('RER CZ/EZ decomp, QoQ @ar','bold', true);
  rep.series('RER',(d.L_Z_EUR-d.L_Z_EUR{-1})*4,'units','PP');
  rep.series('CZK per EUR',(d.L_S_EUR_UNC-d.L_S_EUR_UNC{-1})*4,'units','PP');
  rep.series('Domestic Core inflation',-(d.L_CPIXFE-d.L_CPIXFE{-1})*4,'units','PP');
  rep.series('EZ core inflation',(d.L_CPIXFE_EZ-d.L_CPIXFE_EZ{-1})*4,'units','PP');
  
  rep.subheading('');
  
  rep.subheading('GDP Growth, QoQ @ar','bold', true);
  rep.series('GDP Growth',(d.L_GDP-d.L_GDP{-1})*4,'units','PP');
  rep.series('GDP Output Gap',(d.L_GDP_GAP-d.L_GDP_GAP{-1})*4,'units','PP');
  rep.series('GDP potential',(d.L_GDP_BAR-d.L_GDP_BAR{-1})*4,'units','PP');

  

%% graphs settings
rng   = Plotrng(1):Plotrng(end);
hglt = fcstrng;

% styles
  st1 = struct();
  st1.line.lineWidth = {1.5,1.5};
  st1.line.lineStyle = {'-','--'};
  st1.line.color = {[0,0,0.9],[0,0,0]};
  st1.line.marker = {'none','none'};
  
  st2 = st1;
  st2.line.lineWidth = {1,1};
  
  st3 = st1;
  st3.line.lineStyle = {'-','--','-.'};
  st3.line.Color = {[0,0,0.9],[0,0,0],[0.9,0,0]};
  st3.line.Marker = {'none','none','none'};
  
  sto =struct();
  sto.line.linewidth = {2};
  sto.line.color = {[0,0.9,0],[0,0,0.9],[0.9,0,0],[0.4,0.4,0]};
%% Decompositions    
  % IS curve
  fh = figure('visible','off');
  u = [d.b1*d.E1_L_GDP_GAP, d.b2*d.L_GDP_GAP{-1}, -d.b3*d.RR4_GAP{-1}, ...
      d.b4*d.L_REER_GAP{-1}, +d.b5*d.L_GDP_GAP_RW, ...
      + d.SHK_L_GDP_GAP];
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
  p = plot(rng, [d.L_GDP_GAP d.L_GDP_GAP],'LineWidth',1.5); grid on;
  set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
  legend('Forward','Backward','RIR gap', 'REER gap',...
      'Foreign Demand','Shock',...
      'location','Southoutside','orientation','horizontal');
  
  rep.userfigure('Real Output Gap (%)', fh);
  
  % Foreign Ygap
  fh = figure('visible','off');
  u = [d.exp_us*d.L_GDP_GAP_US, ...
       d.exp_eu*d.L_GDP_GAP_EU, ...
       d.exp_ja*d.L_GDP_GAP_JA, ...
       d.exp_ch*d.L_GDP_GAP_CH, ...
       d.exp_ea7*d.L_GDP_GAP_EA7, ...
       d.exp_la6*d.L_GDP_GAP_LA6, ...
       d.exp_rc6*d.L_GDP_GAP_RC6];
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
  p = plot(rng, [d.L_GDP_GAP_RW d.L_GDP_GAP_RW],'LineWidth',1.5); grid on;
  set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
  legend('US','EU','JA','CH','EA7','LA6','RC6',...
      'location','Southoutside','orientation','horizontal');
  %highlight(hglt);
  rep.userfigure('Foreign Effective Output Gap (%)', fh);
  
  % Foreign Zgap
  fh = figure('visible','off');
  u = [d.imp_us*d.L_Z_GAP, ... 
      d.imp_eu*(d.L_Z_GAP-d.L_Z_GAP_EU), ...
      d.imp_ja*(d.L_Z_GAP-d.L_Z_GAP_JA), ...
      d.imp_ch*(d.L_Z_GAP-d.L_Z_GAP_CH), ...
      d.imp_ea7*(d.L_Z_GAP-d.L_Z_GAP_EA7), ...
      d.imp_la6*(d.L_Z_GAP-d.L_Z_GAP_LA6), ...
      d.imp_rc6*(d.L_Z_GAP-d.L_Z_GAP_RC6)];
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
  p = plot(rng, [d.L_REER_GAP d.L_REER_GAP],'LineWidth',1.5); grid on;
  set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
  legend('US','EU','JA','CH','EA7','LA6','RC6',...
      'location','Southoutside','orientation','horizontal');
  %highlight(hglt);
  rep.userfigure('Real Effective Exchange Rate Gap (%)', fh);
  
  % phillips curve
  fh = figure('visible','off');
  u = [d.a1*d.E4_D4L_CPIXFE, (1-d.a1)*d.D4L_CPIXFE{-1}, ...
      + d.a2*(d.DL_REER_GAP), ...
      + d.a3*d.L_REER_GAP, ...
      + d.a4*(d.L_QOIL_GAP+d.L_Z_GAP), ...
      + d.a5*(d.L_QFOOD_GAP+d.L_Z_GAP), ...
      + d.a6*(d.L_GDP_GAP{-1}), ...
      + d.SHK_DLA_CPIXFE];
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
  p = plot(rng, [d.DLA_CPIXFE d.DLA_CPIXFE d.D4L_CPI_TAR]); grid on;
  set(p,{'linewidth'},{2.5;1.5;1.5},{'color'},{'w';'k';'k'},{'linestyle'},{'-';'-';'--'});
  legend('Exp.','Lag','Chng. in REER Gap','REER gap',...
      'Oil', 'Food','Y gap','Shock',...
      'location','Southoutside','orientation','horizontal');
  %highlight(hglt);
  rep.userfigure('Core Inflation Phillipse Curve (% QoQ @ar, log approx)', fh);
  
  % MP rule
  fh = figure('visible','off');
  u = [d.g1*d.RS{-1},...
      + (1-d.g1)*(d.RS_NEUTRAL), ...
      + (1-d.g1)*d.g2*(d.D4L_CPI_DEV), ...
      + (1-d.g1)*d.g4*d.L_GDP_GAP,...
      + d.SHK_RS];
  %       + (1-d.g1)*d.g3*d.E8_P_GAP,...
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
  p = plot(rng, [d.RS d.RS],'LineWidth',1.5); grid on;
  set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
  legend('Lag','Neutral','Inflation Deviation','Output Gap','Shock',...
      'location','Southoutside','orientation','horizontal');
  %highlight(hglt);
  rep.userfigure('Policy Rate (%, p.a.)', fh);
  
  % UIP 
  fh = figure('visible','off');
  u = [d.CTYPREM,...
       d.c1_L_S*4*(d.E1_L_S-d.L_S),...
       (1-d.c1_L_S)*(2*(d.DLA_Z_BAR-d.D4L_CPI_TAR_US+d.D4L_CPI_TAR)-d.DLA_S),...       
       4*d.SHK_L_S];
    [upos, uneg] = posneg(u, rng);
    bar(rng,upos,'stack');hold on; bar(rng,uneg, 'stack');hold on;
p = plot(rng, [d.RS-d.RS_US d.RS-d.RS_US],'LineWidth',1.5); grid on;
  set(p,{'linewidth'},{2.5;1.5},{'color'},{'w';'k'});
  legend('Long Premium','Exp. Deprec','Trend Deprec','UIP Shock',...
      'location','Southoutside','orientation','horizontal');
  %highlight(hglt);
  rep.userfigure('Interest Rate Differencial (p.p., p.a.)', fh);
    
  %% Relative Prices
  
  f = figure('visible','off');
  subplot(211)
  p = plot(qq(2005,1):Plotrng(end),[d.L_Z d.L_Z_BAR],'linewidth', 2);
  legend('level','tnd','location','SW');
  title('RER wrt USD');
  grid;
  highlight(hglt);
  subplot(212)
  p = plot(qq(2005,1):Plotrng(end),d.L_Z_GAP,'linewidth', 2);
  title('RER GAP wrt USD');
  grid;  
  highlight(hglt);
  rep.userfigure('',f);
  
  f = figure('visible','off');
  subplot(211)
  p = plot(qq(2005,1):Plotrng(end),[d.L_Z_EUR d.L_Z_BAR_EUR],'linewidth', 2);
  legend('level','tnd','location','SW');
  title('RER wrt EUR');
  grid;
  highlight(hglt);
  subplot(212)
  p = plot(qq(2005,1):Plotrng(end),d.L_Z_GAP_EUR,'linewidth', 2);
  title('RER GAP wrt EUR');
  grid;
  highlight(hglt);
  rep.userfigure('',f);
 
%  %% Steady State Graphs
% 
% % Steady State Graphs - Overview
% f = figure('visible','off');
% 
% subplot(2,2,1);
% plot(rng,[d.D4L_CPIXFE d.D4L_CPI_TAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('core','CPI tar','location','NW');
% title('Core CPI Inflation (% YoY)');
% 
% subplot(2,2,2);
% plot(rng,[d.D4L_CPI d.D4L_CPI_TAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('Headline','CPI tar','location','NW');
% title('Headline CPI Inflation (% YoY)');
% 
% subplot(2,2,3);
% plot(rng,[d.L_RP d.L_RP_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('Core/Headline','tnd','location','NW');
% title('Core/Headline RP (100*log)');
% 
% rep.userfigure('Steady State Graphs - Prices',f);
%   
% 
% % Steady State Graphs - Prices
% f = figure('visible','off');
% subplot(2,2,1);
% plot(rng,[d.UNR d.NAIRU],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('Unemploymnet','NAIRU');
% title('Unemploymnet (pct)');
% 
% subplot(2,2,2);
% plot(rng,[d.L_GDP d.L_GDP_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd','location','SE');
% title('Real Output (100*log)');
% 
% subplot(2,2,3);
% plot(rng,[4*diff(d.L_GDP) 4*diff(d.L_GDP_BAR)],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd');
% title('Real Output Growth (QoQ @ar)');
% 
% subplot(2,2,4);
% plot(rng,[d.L_GDP_GAP],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% title('Output Gap (100*log)');
% 
% rep.userfigure('Steady State Graphs - Output',f);
% 
% 
% 
% % Steady State Graphs - Interest Rates
% f = figure('visible','off');
% 
% subplot(2,2,1);
% plot(rng,[d.RS d.RS_NEUTRAL],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('Nominal Rate','Neutral Rate');
% title('Nominal Interest Rate (% pa)');
% 
% subplot(2,2,2);
% plot(rng,[d.RR d.RR_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('Rate','Bar');
% title('Real Interest Rate (% pa)');
% 
% subplot(2,2,3);
% plot(rng,[d.RR4 d.RR4_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('Rate','Bar');
% title('1Y Real Interest Rate (% pa)');
% 
% subplot(2,2,4);
% plot(rng,[d.CTYPREM d.RR_BAR-d.RR_BAR_US-d.DLA_Z_BAR{+1}],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','end. tnd','Location','SW');
% title('Country Risk Premium (% pa)');
% 
% rep.userfigure('Steady State Graphs - Interest Rates',f);
% 
% f = figure('visible','off');
% p = plot(qq(2005,1):qq(2018,2),[d.L_GDP_GAP tseries(qq(2005,1):qq(2018,2),0)],'LineWidth',2);
% set(p(1:2),'linewidth',2);
% set(p(2),'linestyle','--','color','k');
% grid on;
% highlight(fcstrng);
% %legend('Nominal Rate','Neutral Rate');
% title('Mezera vstupu (pp)');
% rep.userfigure('Output Gap',f);
% 
% 
% 
% % Steady State Graphs - Exchange Rates
% f = figure('visible','off');
% 
% subplot(2,2,1);
% plot(rng,[d.DLA_S d.DLA_S_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd');
% title('Nominal Exchange Rate (% QoQ @ar, depr. up)');
% 
% subplot(2,2,2);
% plot(rng,[d.S],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% title('Nominal Exchange Rate to US (CZK per USD)');
% 
% subplot(2,2,3);
% plot(rng,[d.DLA_Z d.DLA_Z_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd');
% title('Real Exchange Rate (% QoQ @ar, depr. up)');
% 
% subplot(2,2,4);
% plot(rng,[d.L_Z d.L_Z_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd','Location','SouthEast');
% title('Real Exchange Rate to US (100*log)');
% 
% rep.userfigure('Steady State Graphs - Exchange Rates wrt US',f);
% 
% f = figure('visible','off');
% 
% subplot(2,2,1);
% plot(rng,[(d.L_S_EUR_UNC-d.L_S_EUR_UNC{-1})*4 d.DLA_S_EUR_BAR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd','Location','SW');
% title('Nominal Exchange Rate (% QoQ @ar, depr. up)');
% 
% subplot(2,2,2);
% plot(rng,[exp(d.L_S_EUR_UNC/100)],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% title('Nominal Exchange Rate (CZK per EUR)');
% 
% subplot(2,2,3);
% plot(rng,[(d.L_Z_EUR-d.L_Z_EUR{-1}) (d.L_Z_BAR_EUR-d.L_Z_BAR_EUR{-1})*4],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd','Location','SW');
% title('Real Exchange Rate (% QoQ @ar, depr. up)');
% 
% subplot(2,2,4);
% plot(rng,[d.L_Z_EUR d.L_Z_BAR_EUR],'LineWidth',2);
% grid on;
% highlight(fcstrng);
% legend('level','tnd','Location','SW');
% title('Real Exchange Rate to EUR (100*log)');
% 
% rep.userfigure('Steady State Graphs - Exchange Rates wrt EZ',f);

  %% Shocks
  
  var_per_page = 30;% number of shocks on one page
  
  enames = get(m,'enames');
  nVar = numel(enames);
  nPage = ceil(nVar/var_per_page);

    for iPage = 1:nPage
      if iPage == 1
       rep.table('Residuals  & Expert Judgement','range',fcstrng(1):Tablerng(end),...
           'vline',fcstrng(1)-1,'decimal',1,'dateformat','YYFP');
      else
       rep.table('Residuals  & Expert Judgement Cont.','range',fcstrng(1):Tablerng(end),...
           'vline',fcstrng(1)-1,'decimal',1,'dateformat','YYFP');
      end
      for ind = ((iPage-1)*var_per_page+1):min(iPage*var_per_page,nVar)
	  rep.series(enames{ind}, d.([enames{ind}]));
      end
    end
    
    %     %% Tunes overview
% 
% rep.table('Position of tunes','range',fcstrng(1):Tablerng(end),'vline',fcstrng(1)-1,'decimal',0,'dateformat','YYFP');
%   for ind = 1:numel(enames);
% 	  rep.series(enames{ind}, plan.(enames{ind}));
%   end
    
  %% Preparation fancharts
d.enames = get(m,'enames');
xnames = get(m, 'xnames');

% Beginning of the fanchart -- set std deviation of variables equal to zero
for iter=1:length(xnames)
    if isnan(d.(xnames{iter})(fcstrng(1)-1))
        d.(xnames{iter})(fcstrng(1)-1)=0;
    end
end

% This gives us the range taken from the std dev.
stdRange = dbbatch(d, '$0', 'get(d.$0, ''range'')', 'namelist', xnames);

% set confidence level (works only for 4 conf interval)
clev     = [.9 .6 .3];
clevdesc = {'90%','60%','30% Confidence Interval'};


for iter1=1:numel(xnames)
    %get the confbands of normal distribution
    cf = norm_confbands(clev,d.(xnames{iter1})(:));
    for iter2=1:size(cf,2)
        % shift by mean
        cf(:,iter2)=cf(:,iter2) + d.(xnames{iter1})(stdRange.(xnames{iter1}));
    end
    %save the line of confidence in s_check struct
    d.cfBands.(xnames{iter1}) = tseries(stdRange.(xnames{iter1}),cf);
end  

f = figure('visible','off');

subplot(221)
shaded_plot(d.cfBands.RS(fcstrng(1):fcstrng(end)), fcstrng(1):fcstrng(end), clev, 'interp', false);
plot(fcstrng(1)-12:fcstrng(end),d.RS,'LineWidth',1.5,'color','k');
plot([dat2dec(fcstrng(1)-1,'centre');dat2dec(fcstrng(1)-1,'centre')],ylim,'k:','LineWidth',.5);
hold on; plot(fcstrng(1)-12:fcstrng(end),tseries(fcstrng(1)-12:fcstrng(end),0),...
    'LineWidth',.5,'linestyle','--','color','k');
title('Nominal Interbank Interest Rate, percent p.a.');
l = legend(clevdesc);
set(l,'Orientation','Horizontal','Location','SouthOutside','Box','off');
lPosition=get(l,'Position');
lPosition(2)=lPosition(2)-0.08;
set(l,'Position',lPosition);

subplot(222)
%shaded_plot(exp(d.cfBands.L_S_EUR(fcstrng(1):fcstrng(end))/100), fcstrng(1):fcstrng(end), clev, 'interp', false);
plot(fcstrng(1)-12:fcstrng(end),exp(d.L_S_EUR/100),'LineWidth',1.5,'color','k');
plot([dat2dec(fcstrng(1)-1,'centre');dat2dec(fcstrng(1)-1,'centre')],ylim,'k:','LineWidth',.5);
title('CZK per EUR');

subplot(223)
shaded_plot(100*exp(d.cfBands.D4L_CPIXFE(fcstrng(1):fcstrng(end))/100)-100, fcstrng(1):fcstrng(end), clev, 'interp', false);
plot(fcstrng(1)-12:fcstrng(end),100*exp(d.D4L_CPIXFE/100)-100,'LineWidth',1.5,'color','k');
plot([dat2dec(fcstrng(1)-1,'centre');dat2dec(fcstrng(1)-1,'centre')],ylim,'k:','LineWidth',.5);
hold on; plot(fcstrng(1)-12:fcstrng(end),tseries(fcstrng(1)-12:fcstrng(end),0),...
    'LineWidth',.5,'linestyle','--','color','k');
title('CPI Core Inflation, percent YoY');

subplot(224)
shaded_plot(100*exp(d.cfBands.D4L_GDP(fcstrng(1):fcstrng(end))/100)-100, fcstrng(1):fcstrng(end), clev, 'interp', false);
plot(fcstrng(1)-12:fcstrng(end),100*exp(d.D4L_GDP/100)-100,'LineWidth',1.5,'color','k');
plot([dat2dec(fcstrng(1)-1,'centre');dat2dec(fcstrng(1)-1,'centre')],ylim,'k:','LineWidth',.5);
hold on; plot(fcstrng(1)-12:fcstrng(end),tseries(fcstrng(1)-12:fcstrng(end),0),...
    'LineWidth',.5,'linestyle','--','color','k');
title('Real GDP, percent YoY');

rep.userfigure('Macroeconomic Forecast -- Czech Republic', f);

rep.publish(['results/' fName], 'display', false);

 rmpath('utils');
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

end