function cfBands = make_confidence_bands(m, mean, std, clev)
  
% Make confidence bands for all model variables  

  cfBands = dbempty();
  xnames=get(m,'xnames');
  logVars=get(m,'log');

  for iter1=1:numel(xnames)
    if logVars.(xnames{iter1}) % cf bands for log variables
       std.(xnames{iter1})(get(std.(xnames{iter1}),'first')-1) = 1;
       rng = get(std.(xnames{iter1}),'range');  
      cf = norm_confbands(clev, log(std.(xnames{iter1})(rng)));
      for iter2=1:size(cf,2)
        cf(:,iter2)= exp(cf(:,iter2)+log(mean.(xnames{iter1})(rng)));
      end
    else
      std.(xnames{iter1})(get(std.(xnames{iter1}),'first')-1) = 0;
      rng = get(std.(xnames{iter1}),'range');  
      cf = norm_confbands(clev, std.(xnames{iter1})(rng));
      for iter2=1:size(cf,2)
        cf(:,iter2)=cf(:,iter2)+mean.(xnames{iter1})(rng);
      end
    end
    cfBands.(xnames{iter1}) = tseries(rng,cf);
  end
end

function cf=norm_confbands(clev,forecastStd)

% Subfunction calculates confidence intervals specified in clev for normal
% distributions with zero mean and std. deviations stored in vector
% forecastStd.

  np=length(forecastStd);

  % precalculate the confidence intervals for normal(0,1)
  mult = zeros(1,length(clev));
  for iter=1:length(clev)
    mult(iter) = -sqrt(2)*erfcinv((1-clev(iter)));% norminv(p)=-sqrt(2)*erfcinv(2*p)
  end

  % create the confbands
  cf = zeros(np, 2*length(clev)+1);
  for iter=1:length(clev)
    cf(:,iter) = +mult(iter)*forecastStd;
    cf(:,end-iter+1) = -mult(iter)*forecastStd;
  end
end