% % create a shaded plot
% %
% % author: Ondra Kamenik
% %
% % y      variable timeseries including the bands. It must have an even
% %        number of columns, the middle one is the median. The rows
% %        correspond to periods.
% % rng    the range of the plot plot and data y. Length of the range must
% %        be the same as a number of rows in y
% % clev   confidence levels for example [0.90 0.70 0.50 0.30 0.1].
% %        in this case y must have 11 timeseries
% % interp if true, interpolation is done, otherwise one color areas are
% %        plotted, default is true 
% %
% % the function returns the axes handle
% 
% function ah = shaded_plot(y, rng, clev, varargin)
% 
% % get options
% optnames = {varargin{1:2:end}};
% optvals = {varargin{2:2:end}};
% opt = cell2struct(optvals, optnames, 2);
% 
% % blue shaded plot
% A = [153 153 153;
%     153 204 255;
%     %102 178 255;
%     51 153 255;
%     %0 128 255;
%     0 102 204;
%     0 76 153;
%     0 51 102;
%     0 25 51]/255;
% 
% %colormap(repmat([180:-1:40]'/255,1,3));
% colormap(A);
% if any(any((isnan(y))))
%   error('Time series data include NaN');
% end
% if size(y,1) ~= length(rng)
%   error('Incompatible size of data and range');
% end
% if size(y,2) ~= length(clev)*2+1
%   error('Incompatible number of confidence levels wrt the data');
% end
% %x = dat2dec(rng);
% x = dat2dec(rng, 'centre');%use dat2grid because dat2dec converts 2009Q3 to 2009.5, 2009Q4 to 2009.75 and so on, which is not compatible with plot(tseries)
% xx = [x';x(end:-1:1)']; 
% ddens = [(1-clev) 1 (1-clev(end:-1:1))];
% np = length(x);
% 
% for i=1:size(y,2)-1
%   yy = [y(:,i); y(end:-1:1,i+1)];
%   cc = [repmat(ddens(i)*255,np,1); repmat(ddens(i+1)*255,np,1)];
%   if isfield(opt, 'interp') && ~ opt.interp
%     ii = i+1;
%     if i == round(size(y,2)/2)
%         ii = i;
%     elseif i > size(y,2)/2
%       ii = size(y,2)-i+1;
%     end
%     patch(xx, yy, A(ii,:), 'LineStyle','none');%repmat(0.2+0.8*(1-ddens(ii)),1,3).^(1/2)
%   else
%     patch(xx, yy, cc, 'LineStyle','none');
%   end
%   %keyboard
% end
% hold on;
% 
% ah = gca;

% create a shaded plot
%
% author: Ondra Kamenik
%
% y      variable timeseries including the bands. It must have an even
%        number of columns, the middle one is the median. The rows
%        correspond to periods.
% rng    the range of the plot plot and data y. Length of the range must
%        be the same as a number of rows in y
% clev   confidence levels for example [0.90 0.70 0.50 0.30 0.1].
%        in this case y must have 11 timeseries
% interp if true, interpolation is done, otherwise one color areas are
%        plotted, default is true 
%
% the function returns the axes handle

function ah = shaded_plot(y, rng, clev, varargin)

% get options
optnames = {varargin{1:2:end}};
optvals = {varargin{2:2:end}};
opt = cell2struct(optvals, optnames, 2);

% blue shaded plot
A = [153 153 153;
    153 204 255;
    %102 178 255;
    51 153 255;
    %0 128 255;
    0 102 204;
    0 76 153;
    0 51 102;
    0 25 51]/255;

%colormap(repmat([180:-1:40]'/255,1,3));
colormap(A);
if any(any((isnan(y))))
  error('Time series data include NaN');
end
if size(y,1) ~= length(rng)
  error('Incompatible size of data and range');
end
if size(y,2) ~= length(clev)*2+1
  error('Incompatible number of confidence levels wrt the data');
end
% 
% for i = 1:size(y,2)
%     a = y(end-20:end,i);
%     if ~isempty(a(a<0))
%         y(:,i+2:end+1) = y(:,i+1:end);
%         %y(end-20,i+1) = y(end-20,i);
%         y(end-20:end,i+1) = 0;
%     end
% end
%x = dat2dec(rng);
x = dat2dec(rng, 'centre');%use dat2grid because dat2dec converts 2009Q3 to 2009.5, 2009Q4 to 2009.75 and so on, which is not compatible with plot(tseries)
xx = [x';x(end:-1:1)']; 
%ddens = [(1-clev) 1 (1-clev(end:-1:1))];
%np = length(x);
%keyboard
for i=1:size(y,2)-1
  yy = [y(:,i); y(end:-1:1,i+1)];
  %cc = [repmat(ddens(i)*255,np,1); repmat(ddens(i+1)*255,np,1)];
  if isfield(opt, 'interp') && ~ opt.interp
    ii = i+1;
%     if i == 1 && size(y,2) == 8
%         ii = i;
    if i == round(size(y,2)/2)
        ii = i;
    elseif i > size(y,2)/2
      ii = size(y,2)-i+1;
    end
    patch(xx, yy, A(ii,:), 'LineStyle','none');%repmat(0.2+0.8*(1-ddens(ii)),1,3).^(1/2)
%   else
%     patch(xx, yy, cc, 'LineStyle','none');
  end
  %keyboard
end
hold on;

ah = gca;

